

%bcond bootstrap 0
%bcond tomlkit %{without bootstrap}
%bcond tests %{without bootstrap}
%bcond manpages 1

%if %{undefined py3_test_envvars}
%define py3_test_envvars %{shrink:
PYTHONPATH=%{buildroot}%{python3_sitelib}
PATH=%{buildroot}%{_bindir}:${PATH}
}
%endif

Summary:        CLI for working with TOML files. Pronounced "tom clee."
Name:           tomcli
Version:        0.6.0
Release:    1%{?dist}

License:        MIT
URL:            https://sr.ht/~gotmax23/tomcli
%global furl    https://git.sr.ht/~gotmax23/tomcli
Source0:        %{furl}/refs/download/v%{version}/tomcli-%{version}.tar.gz
Source1:        %{furl}/refs/download/v%{version}/tomcli-%{version}.tar.gz.asc
Source2:        https://meta.sr.ht/~gotmax23.pgp

BuildArch:      noarch
BuildRequires:  gnupg2
BuildRequires:  python3-devel
%if %{with manpages}
BuildRequires:  scdoc
%endif

Requires:       (%{py3_dist tomcli[tomlkit]} or %{py3_dist tomcli[tomli]})
%if %{with tomlkit}
Suggests:       %{py3_dist tomcli[tomlkit]}
Recommends:     %{py3_dist tomcli[all]}
%endif


%description
tomcli is a CLI for working with TOML files. Pronounced "tom clee."


%prep
%gpgverify -d0 -s1 -k2
%autosetup -p1


%generate_buildrequires
%{pyproject_buildrequires %{shrink:
    -x tomli
    %{?with_tomlkit:-x all,tomlkit}
    %{?with_tests:-x test}
}}


%build
%pyproject_wheel

%if %{with manpages}
for page in doc/*.scd; do
    dest="${page%.scd}"
    scdoc <"${page}" >"${dest}"
done
%endif


%install
%pyproject_install
%pyproject_save_files tomcli

install -Dpm 0644 doc/*.1 -t %{buildroot}%{_mandir}/man1

(
export %{py3_test_envvars}
%{python3} compgen.py \
    --installroot %{buildroot} \
    --bash-dir %{bash_completions_dir} \
    --fish-dir %{fish_completions_dir} \
    --zsh-dir %{zsh_completions_dir}
)


%check
(
export %{py3_test_envvars}
TOMCLI="%{buildroot}%{_bindir}/tomcli"
cp pyproject.toml test.toml
name="$($TOMCLI get test.toml project.name)"
test "${name}" = "tomcli"

$TOMCLI set test.toml str project.name not-tomcli
newname="$($TOMCLI get test.toml project.name)"
test "${newname}" = "not-tomcli"
)

%if %{with tests}
%pytest
%endif

%package -n tomcli+tomlkit
Summary: Subpackage for tomcli with extra tomlkit dependencies
Requires: tomcli

%description -n tomcli+tomlkit
This is the subpackage for tomcli with extra tomlkit dependencies.

%files -n tomcli+tomlkit -f %{_pyproject_ghost_distinfo}


%package -n tomcli+tomli
Summary: Subpackage for tomcli with extra tomli dependencies
Requires: tomcli

%description -n tomcli+tomli
This is the subpackage for tomcli with extra tomli dependencies.

%files -n tomcli+tomli -f %{_pyproject_ghost_distinfo}



%files -f %{pyproject_files}
%license LICENSE
%doc README.md
%doc NEWS.md
%{_bindir}/tomcli*
%{bash_completions_dir}/tomcli*
%{fish_completions_dir}/tomcli*.fish
%{zsh_completions_dir}/_tomcli*
%{_mandir}/man1/tomcli*.1*


%changelog
* Mon Aug 19 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.6.0-1
- initial build
